@@ -325,15 +325,20 @@ class ApiBackendMatplotlib(rna.plotting.ApiBackend):
         source = rna.path.resolve(source)
         rna.path.cp(source, path)
 
-    def set_style(self, style="rna", dest=None, upgrade=False):
+    def set_style(
+        self,
+        style: str = "rna",
+        dest: typing.Optional[str] = None,
+        upgrade: bool = False,
+    ):
         """
-        Set the matplotlib style of name
-        Important:
-            Either you
+        Set the matplotlib style
+
         Args:
-            style (str)
-            dest (str): local directory to use file from. if None, use default
+            style: name of style
+            dest: mplstydirectory that stores the mplstyle. if None, use default
                 maplotlib destination
+            upgrade: if True copy the style to the source destination (dest)
         """
         if dest is None:
             dest = mpl.get_configdir()
@@ -504,7 +509,7 @@ class ApiBackendMatplotlib(rna.plotting.ApiBackend):
                 with open(path, "w") as f:
                     f.writelines(content)
 
-    @rna.plotting.plot_method
+    @rna.plotting.plot_signature
     def plot_function(self, axes, fun, **kwargs):
         """
         Args:
@@ -528,7 +533,7 @@ class ApiBackendMatplotlib(rna.plotting.ApiBackend):
         artist = axes.plot(*args, **kwargs)
         return artist
 
-    @rna.plotting.plot_method
+    @rna.plotting.plot_signature
     def plot_errorbar(self, axes, points, errors_up, errors_down=None, **kwargs):
         """
         Args:
@@ -575,7 +580,7 @@ class ApiBackendMatplotlib(rna.plotting.ApiBackend):
 
         return artists
 
-    @rna.plotting.plot_method
+    @rna.plotting.plot_signature
     def plot_tensor(
         self,
         axes,
@@ -637,7 +642,7 @@ class ApiBackendMatplotlib(rna.plotting.ApiBackend):
             raise NotImplementedError("Only Scalars and Vectors implemented")
         return artists
 
-    @rna.plotting.plot_method
+    @rna.plotting.plot_signature
     def plot_mesh(self, axes, vertices, faces, **kwargs):
         """
         Args:
@@ -666,7 +671,7 @@ class ApiBackendMatplotlib(rna.plotting.ApiBackend):
             import tfields
 
             mesh = tfields.Mesh3D(vertices, faces=faces)
-            facecolors = self.retrieve_chain(
+            facecolors = self.retrieve(
                 kwargs, "facecolors", "color", default=0, keep=False
             )
             if full:
@@ -717,7 +722,7 @@ class ApiBackendMatplotlib(rna.plotting.ApiBackend):
             )
         elif dim == 3:
             label = kwargs.pop("label", None)
-            color = self.retrieve_chain(
+            color = self.retrieve(
                 kwargs, "color", "c", "facecolors", default="grey", keep=False
             )
             from rna.plotting.colors import color_fmt
@@ -773,7 +778,7 @@ class ApiBackendMatplotlib(rna.plotting.ApiBackend):
 
         return artist
 
-    @rna.plotting.plot_method
+    @rna.plotting.plot_signature
     def plot_sphere(self, axes, point, radius, **kwargs):
         # Make data
         u = np.linspace(0, 2 * np.pi, 100)
@@ -785,7 +790,7 @@ class ApiBackendMatplotlib(rna.plotting.ApiBackend):
         # Plot the surface
         return axes.plot_surface(x, y, z, **kwargs)
 
-    @rna.plotting.plot_method
+    @rna.plotting.plot_signature
     def plot_plane(self, axes, point, normal, **kwargs):
         def rotation_matrix(d):
             sin_angle = np.linalg.norm(d)
@@ -834,7 +839,7 @@ class ApiBackendMatplotlib(rna.plotting.ApiBackend):
         pathpatch_2d_to_3d(patch, z=0, normal=normal)
         pathpatch_translate(patch, (point[0], point[1], point[2]))
 
-    @rna.plotting.plot_method
+    @rna.plotting.plot_signature
     def autoscale_3d(self, axes, array=None, xLim=None, yLim=None, zLim=None):
         if array is not None:
             xMin, yMin, zMin = array.min(axis=0)
@@ -858,7 +863,7 @@ class ApiBackendMatplotlib(rna.plotting.ApiBackend):
         axes.set_ylim([yMin, yMax])
         axes.set_zlim([zMin, zMax])
 
-    @rna.plotting.plot_method
+    @rna.plotting.plot_signature
     def set_legend(self, axes, *artists, **kwargs):
         """
         Convenience method to set a legend from multiple artists to an axes.
@@ -895,7 +900,7 @@ class ApiBackendMatplotlib(rna.plotting.ApiBackend):
             ...              label=(r"$i = 3$,$j = 3$"))
             >>> handles = [im1, im2, im3, im4, im5, im6, im7, im8, im9]
 
-            >>> rna.plotting.set_legend(*handles, table=True, axes=ax)
+            >>> legend = rna.plotting.set_legend(*handles, table=True, axes=ax)
 
             >>> rna.plotting.show()
         """
@@ -1018,15 +1023,29 @@ class ApiBackendMatplotlib(rna.plotting.ApiBackend):
         axes.set_ylim3d([ymean - plot_radius, ymean + plot_radius])
         axes.set_zlim3d([zmean - plot_radius, zmean + plot_radius])
 
-    @rna.plotting.plot_method
+    def set_limits(self, axes, *limits):
+        """
+        Args:
+            *limits: list of 2-tuples containing min and max limit of axes
+        """
+        dim = self.axes_dim(axes)
+        for coord, limit in zip(["x", "y", "z"][:dim], limits):
+            if dim == 2:
+                set_method = getattr(axes, "set_" + coord + "lim")
+            elif dim == 3:
+                set_method = getattr(axes, "set_" + coord + "limd3")
+
+            set_method(*limit)  # limit = xmin, xmax
+
+    @rna.plotting.plot_signature
     def set_formatter(
         self, axes, sub_axes=None, formatter=dates.DateFormatter("%d-%m-%y")
     ):
         """
         Examples:
             >>> from rna.plotting.backends.matplotlib import ApiBackendMatplotlib
-            >>> axes = ApiBackendMatplotlib.gca()
-            >>> ApiBackendMatplotlib.set_formatter(axes)
+            >>> axes = ApiBackendMatplotlib().gca()
+            >>> ApiBackendMatplotlib().set_formatter(axes)
         """
         if sub_axes is None:
             sub_axes = axes.xaxis
@@ -1050,12 +1069,12 @@ class ScientificFormatter(mpl.ticker.ScalarFormatter):
 
     def __init__(self, oom=None, **kwargs):
         self._oom = oom
-        super(ScientificFormatter, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
-    def _set_orderOfMagnitude(self, oom):
-        self._exp = int(np.log10(oom))
+    def _set_orderOfMagnitude(self, oom):  # pylint: disable=invalid-name
+        exp = int(np.log10(oom))
         if self._oom is not None:
             oom = self._oom
         else:  # Default: -3, 0, 3, 6, ...
-            oom = self._exp - (self._exp % 3)
+            oom = exp - (exp % 3)
         self.orderOfMagnitude = oom
