@@ -3,6 +3,7 @@ Various polymorphisms which can be used as mixins
 """
 import pathlib
 import typing
+import logging
 import io
 from six import string_types
 
@@ -37,8 +38,9 @@ class Storable:
         path: typing.Union[str, io.IOBase],
         *args: [str],
         create_parents: bool = True,
+        extension: typing.Optional[typing.Union[str, typing.List[str]]] = None,
         **kwargs
-    ):
+    ) -> None:
         """
         Saving by redirecting to the correct save method depending on path.
         Implement _save_{extension}(self, path, **kwargs) for saving to your extension of choice
@@ -46,20 +48,31 @@ class Storable:
         Args:
             path (str | buffer)
             *args: joined with path
-            create_parents:
+            create_parents: create the parent dir(s) if required
             **kwargs:
-                extension (str): only needed if path is buffer
+                extension (str | List[str]): explicit extension required if path is buffer,
+                    if list of extensions save as all extension formats.
                 ... remaining:forwarded to extension specific method
         """
         # get the extension
+        if isinstance(extension, list):
+            for ext in extension:
+                print(ext)
+                self.save(
+                    path, *args, create_parents=create_parents, extension=ext, **kwargs
+                )
+            return
+
         if isinstance(path, (string_types, pathlib.Path)):
             path = rna.path.resolve(path, *args)
-            extension = kwargs.pop("extension", pathlib.Path(path).suffix.lstrip("."))
-        else:
-            extension = kwargs.pop("extension", None)
-
+            if extension is None:
+                extension = pathlib.Path(path).suffix.lstrip(".")
+            if not path.endswith(extension):
+                path += "." + extension
         if not extension:
-            raise ValueError("Path requires extension for auto rooting.")
+            raise ValueError(
+                "Path {path} requires extension for auto rooting.".format(**locals())
+            )
 
         # get the save method
         if (
@@ -83,7 +96,9 @@ class Storable:
         if create_parents:
             rna.path.mkdir(path)
 
-        return save_method(path, **kwargs)
+        log = logging.getLogger(__name__)
+        log.info("Saving to path '%s' with method %s.", path, save_method)
+        save_method(path, **kwargs)
 
     @classmethod
     def load(cls, path: typing.Union[str, io.IOBase], *args: [str], **kwargs):
@@ -119,6 +134,20 @@ class Storable:
 
         return load_method(path, **kwargs)
 
+    def _save_pickle(self, path):
+        import pickle  # pylint:disable = import-outside-toplevel
+
+        with open(path, "wb") as out_file:
+            pickle.dump(self, out_file)
+
+    @classmethod
+    def _load_pickle(cls, path):
+        import pickle  # pylint:disable = import-outside-toplevel
+
+        with open(path, "rb") as in_file:
+            obj = pickle.load(in_file)
+        return obj
+
 
 class Plottable:  # pylint: disable=too-few-public-methods
     """
